@@ -65,7 +65,9 @@ def process_document(filename, pdf_filename, html_filename=None):
     # convert contents to pdf
     default_css = f'{os.path.dirname(os.path.abspath(__file__))}/css/default.css'
     from weasyprint import HTML, CSS
-    css = CSS(default_css)
+    from weasyprint.fonts import FontConfiguration
+    font_config = FontConfiguration()
+    css = CSS(default_css, font_config=font_config)
     HTML(string=html).write_pdf(pdf_filename,
     stylesheets=[css])
 
